<?php
if (!function_exists('magazine_shop_the_custom_logo')):
/**
 * Displays the optional custom logo.
 *
 * Does nothing if the custom logo is not available.
 *
 * @since magazine-shop 1.0.0
 */
function magazine_shop_the_custom_logo() {
	if (function_exists('the_custom_logo')) {
		the_custom_logo();
	}
}
endif;

if (!function_exists('magazine_shop_body_class')):

/**
 * body class.
 *
 * @since 1.0.0
 */
function magazine_shop_body_class($magazine_shop_body_class) {
	global $post;
	$global_layout       = magazine_shop_get_option('global_layout');
	$input               = '';
	$home_content_status = magazine_shop_get_option('home_page_content_status');
	if (1 != $home_content_status) {
		$input = 'home-content-not-enabled';
	}
	// Check if single.
	if ($post && is_singular()) {
		$post_options = get_post_meta($post->ID, 'magazine-shop-meta-select-layout', true);
		if (empty($post_options)) {
			$global_layout = esc_attr(magazine_shop_get_option('global_layout'));
		} else {
			$global_layout = esc_attr($post_options);
		}
	}
	if ($global_layout == 'left-sidebar') {
		$magazine_shop_body_class[] = 'left-sidebar '.esc_attr($input);
	} elseif ($global_layout == 'no-sidebar') {
		$magazine_shop_body_class[] = 'no-sidebar '.esc_attr($input);
	} else {
		$magazine_shop_body_class[] = 'right-sidebar '.esc_attr($input);

	}
	return $magazine_shop_body_class;
}
endif;

add_action('body_class', 'magazine_shop_body_class');
/**
 * Returns word count of the sentences.
 *
 * @since magazine-shop 1.0.0
 */
if (!function_exists('magazine_shop_words_count')):
function magazine_shop_words_count($length = 25, $magazine_shop_content = null) {
	$length          = absint($length);
	$source_content  = preg_replace('`\[[^\]]*\]`', '', $magazine_shop_content);
	$trimmed_content = wp_trim_words($source_content, $length, '...');
	return $trimmed_content;
}
endif;

if (!function_exists('magazine_shop_simple_breadcrumb')):

/**
 * Simple breadcrumb.
 *
 * @since 1.0.0
 */
function magazine_shop_simple_breadcrumb() {

	if (!function_exists('breadcrumb_trail')) {

		require_once get_template_directory().'/assets/libraries/breadcrumbs/breadcrumbs.php';
	}

	$breadcrumb_args = array(
		'container'   => 'div',
		'show_browse' => false,
	);
	breadcrumb_trail($breadcrumb_args);

}

endif;

if (!function_exists('magazine_shop_custom_posts_navigation')):
/**
 * Posts navigation.
 *
 * @since 1.0.0
 */
function magazine_shop_custom_posts_navigation() {

	$pagination_type = magazine_shop_get_option('pagination_type');

	switch ($pagination_type) {

		case 'default':
			the_posts_navigation();
			break;

		case 'numeric':
			the_posts_pagination();
			break;

		default:
			break;
	}

}
endif;

add_action('magazine_shop_action_posts_navigation', 'magazine_shop_custom_posts_navigation');


if (!function_exists('magazine_shop_excerpt_more') && !is_admin()):

/**
 * Implement read more in excerpt.
 *
 * @since 1.0.0
 *
 * @param string $more The string shown within the more link.
 * @return string The excerpt.
 */
function magazine_shop_excerpt_more($more) {

	$flag_apply_excerpt_read_more = apply_filters('magazine_shop_filter_excerpt_read_more', true);
	if (true !== $flag_apply_excerpt_read_more) {
		return $more;
	}

	$output         = $more;
	$read_more_text = esc_html(magazine_shop_get_option('read_more_button_text'));
	if (!empty($read_more_text)) {
		$output = ' <a href="'.esc_url(get_permalink()).'" class="read-more button-fancy -red">'.'<span class="btn-arrow"></span><span class="twp-read-more text">'.esc_html($read_more_text).'</span>'.'</a>';
		$output = apply_filters('magazine_shop_filter_read_more_link', $output);
	}
	return $output;

}

add_filter('excerpt_more', 'magazine_shop_excerpt_more');
endif;


if( class_exists( 'Booster_Extension_Class' ) ){

    add_filter('booster_extemsion_content_after_filter','magazine_shop_after_content_pagination');

}

if( !function_exists('magazine_shop_after_content_pagination') ):

    function magazine_shop_after_content_pagination($after_content){

        $pagination_single = wp_link_pages( array(
                    'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'magazine-shop' ),
                    'after'  => '</div>',
                    'echo' => false
                ) );

        $after_content =  $pagination_single.$after_content;

        return $after_content;

    }

endif;

if( !function_exists('magazine_shop_post_floating_nav') ):

    function magazine_shop_post_floating_nav(){

        $default = magazine_shop_get_default_theme_options();
        $ed_floating_next_previous_nav = get_theme_mod( 'ed_floating_next_previous_nav',$default['ed_floating_next_previous_nav'] );

        if( 'post' === get_post_type() && $ed_floating_next_previous_nav ){

            $next_post = get_next_post();
            $prev_post = get_previous_post();

            if( isset( $prev_post->ID ) ){

                $prev_link = get_permalink( $prev_post->ID );?>

                <div class="floating-post-navigation floating-navigation-prev">
                    <?php if( get_the_post_thumbnail( $prev_post->ID,'medium' ) ){ ?>
                            <?php echo wp_kses_post( get_the_post_thumbnail( $prev_post->ID,'medium' ) ); ?>
                    <?php } ?>
                    <a href="<?php echo esc_url( $prev_link ); ?>">
                        <span class="floating-navigation-label"><?php echo esc_html__('Previous post', 'magazine-shop'); ?></span>
                        <span class="floating-navigation-title"><?php echo esc_html( get_the_title( $prev_post->ID ) ); ?></span>
                    </a>
                </div>

            <?php }

            if( isset( $next_post->ID ) ){

                $next_link = get_permalink( $next_post->ID );?>

                <div class="floating-post-navigation floating-navigation-next">
                    <?php if( get_the_post_thumbnail( $next_post->ID,'medium' ) ){ ?>
                        <?php echo wp_kses_post( get_the_post_thumbnail( $next_post->ID,'medium' ) ); ?>
                    <?php } ?>
                    <a href="<?php echo esc_url( $next_link ); ?>">
                        <span class="floating-navigation-label"><?php echo esc_html__('Next post', 'magazine-shop'); ?></span>
                        <span class="floating-navigation-title"><?php echo esc_html( get_the_title( $next_post->ID ) ); ?></span>
                    </a>
                </div>

            <?php
            }

        }

    }

endif;

add_action( 'magazine_shop_navigation_action','magazine_shop_post_floating_nav',10 );

/**
 * Recommended plugins
 *
 */
function magazine_shop_recommended_plugins() {
	$magazine_shop_plugins = array(
        array(
            'name'      => esc_html__('Demo Import Kit','magazine-shop'),
            'slug'      => 'demo-import-kit',
            'required'  => false,
        ),
        array(
            'name'     => __('WooCommerce', 'magazine-shop'),
            'slug'     => 'woocommerce',
            'required' => false,
        ),
        array(
            'name'     => __('Social Share With Floating Bar', 'magazine-shop'),
            'slug'     => 'social-share-with-floating-bar',
            'required' => false,
        ),
        array(
            'name'      => esc_html__('Themeinwp Import Companion','magazine-shop'),
            'slug'      => 'themeinwp-import-companion',
            'required'  => false,
        ),
	);
	$magazine_shop_plugins_config = array(
		'dismissable' => true,
	);

	tgmpa($magazine_shop_plugins, $magazine_shop_plugins_config);
}

add_action('tgmpa_register', 'magazine_shop_recommended_plugins');
